@@ -22,7 +22,11 @@ class Debugged(object):
 		if exception:
 			etype = type(exception)
 			value = exception
-			tback = sys.last_traceback
+			
+			try:
+				tback = sys.last_traceback
+			except:
+				tback = sys.exc_info()[2]
 
 		exc_info = traceback.extract_tb(tback)
 
@@ -31,14 +35,9 @@ class Debugged(object):
 
 		finished_local_data = {}
 
-		for item in Debugged.default_data.items():
-			if type(item[1]) == type(lambda x:x):
-				item[1] = item[1]()
-			finished_local_data.update([item])
-
-		for item in data.items():
-			if type(item[1]) == type(lambda x:x):
-				item[1] = item[1]()
+		for key, value in Debugged.default_data.items() + data.items():
+			if callable(value):
+				value = value()
 			finished_local_data.update([item])
 
 		def send():
